@@ -37,7 +37,7 @@ bool ClipboardMenu::secondsIncluded() const
     return m_secondsIncluded;
 }
 
-void ClipboardMenu::setSecondsIncluded(const bool &secondsIncluded)
+void ClipboardMenu::setSecondsIncluded(bool secondsIncluded)
 {
     if (m_secondsIncluded != secondsIncluded) {
         m_secondsIncluded = secondsIncluded;
@@ -61,61 +61,44 @@ void ClipboardMenu::setupMenu(QAction *action)
 
         const QDate date = m_currentDate.date();
         const QTime time = m_currentDate.time();
-        const QRegularExpression rx("[^0-9:]");
+        const QRegularExpression rx(QStringLiteral("[^0-9:]"));
         const QChar ws = QLatin1Char(' ');
         QString s;
         QAction *a;
 
-        s = QLocale().toString(date, QLocale::ShortFormat);
+        // e.g 12:30 PM or 12:30:01 PM
+        s = m_secondsIncluded ? QLocale::system().toString(time, QLocale::LongFormat) : QLocale::system().toString(time, QLocale::ShortFormat);
         a = menu->addAction(s);
         a->setData(s);
+
+        // the same as the option above but shows the opposite of the "show seconds" setting
+        // e.g if "show seconds" is enabled it will show the time without seconds and vice-versa
+        s = m_secondsIncluded ? QLocale::system().toString(time, QLocale::ShortFormat) : QLocale::system().toString(time, QLocale::LongFormat);
+        a = menu->addAction(s);
+        a->setData(s);
+
+        // e.g 4/28/22
+        s = QLocale::system().toString(date, QLocale::ShortFormat);
+        a = menu->addAction(s);
+        a->setData(s);
+
+        // e.g Thursday, April 28, 2022
+        s = QLocale::system().toString(date, QLocale::LongFormat);
+        a = menu->addAction(s);
+        a->setData(s);
+
+        // e.g Thursday, April 28, 2022 12:30 PM or Thursday, April 28, 2022 12:30:01 PM -03
+        s = m_secondsIncluded ? QLocale::system().toString(date, QLocale::LongFormat) + ws + QLocale::system().toString(time, QLocale::LongFormat) : QLocale::system().toString(date, QLocale::LongFormat) + ws + QLocale::system().toString(time, QLocale::ShortFormat);
+        a = menu->addAction(s);
+        a->setData(s);
+
+        // e.g 2022-04-28
         s = date.toString(Qt::ISODate);
         a = menu->addAction(s);
         a->setData(s);
-        s = QLocale().toString(date, QLocale::LongFormat);
-        a = menu->addAction(s);
-        a->setData(s);
 
-        menu->addSeparator();
-
-        s = QLocale().toString(time, QLocale::ShortFormat);
-        a = menu->addAction(s);
-        a->setData(s);
-        if (m_secondsIncluded) {
-            s = QLocale().toString(time, QLocale::LongFormat);
-            s.remove(rx);
-            a = menu->addAction(s);
-            a->setData(s);
-            s = QLocale().toString(time, QLocale::LongFormat);
-            a = menu->addAction(s);
-            a->setData(s);
-        }
-
-        menu->addSeparator();
-
-        s = QLocale().toString(time, QLocale::ShortFormat) + ws + QLocale().toString(time, QLocale::ShortFormat);
-        a = menu->addAction(s);
-        a->setData(s);
-        if (m_secondsIncluded) {
-            s = QLocale().toString(time, QLocale::ShortFormat) + ws + QLocale().toString(time, QLocale::LongFormat).remove(rx);
-            a = menu->addAction(s);
-            a->setData(s);
-            s = QLocale().toString(time, QLocale::ShortFormat) + ws + QLocale().toString(time, QLocale::LongFormat);
-            a = menu->addAction(s);
-            a->setData(s);
-        }
-        s = date.toString(Qt::ISODate) + ws + QLocale().toString(time, QLocale::ShortFormat);
-        a = menu->addAction(s);
-        a->setData(s);
-        if (m_secondsIncluded) {
-            s = date.toString(Qt::ISODate) + ws + QLocale().toString(time, QLocale::LongFormat).remove(rx);
-            a = menu->addAction(s);
-            a->setData(s);
-            s = date.toString(Qt::ISODate) + ws + QLocale().toString(time, QLocale::LongFormat);
-            a = menu->addAction(s);
-            a->setData(s);
-        }
-        s = QLocale().toString(date, QLocale::LongFormat) + ws + QLocale().toString(time, QLocale::ShortFormat);
+        // e.g 2022-04-28 12:30 PM or 2022-04-28 12:30:01 PM -03
+        s = m_secondsIncluded ? date.toString(Qt::ISODate) + ws + QLocale::system().toString(time, QLocale::LongFormat) : date.toString(Qt::ISODate) + ws + QLocale::system().toString(time, QLocale::ShortFormat);
         a = menu->addAction(s);
         a->setData(s);
 
