@@ -16,6 +16,8 @@
 #include <QStandardPaths>
 
 #include <KApplicationTrader>
+#include <KDesktopFileActions>
+#include <KFileUtils>
 #include <KIO/ApplicationLauncherJob>
 #include <KLocalizedString>
 #include <KNotificationJobUiDelegate>
@@ -83,9 +85,9 @@ QVariantList createActionListForFileItem(const KFileItem &fileItem)
     if (!services.isEmpty()) {
         list << createTitleActionItem(i18n("Open with:"));
 
-        for (const KService::Ptr service : services) {
+        for (const KService::Ptr &service : services) {
             const QString text = service->name().replace(QLatin1Char('&'), QStringLiteral("&&"));
-            QVariantMap item = createActionItem(text, service->icon(), QStringLiteral("_kicker_fileItem_openWith"), service->entryPath());
+            const QVariantMap item = createActionItem(text, service->icon(), QStringLiteral("_kicker_fileItem_openWith"), service->entryPath());
 
             list << item;
         }
@@ -257,7 +259,7 @@ QVariantList systemSettingsActions()
     return list;
 }
 
-QVariantList recentDocumentActions(KService::Ptr service)
+QVariantList recentDocumentActions(const KService::Ptr &service)
 {
     QVariantList list;
 
@@ -296,7 +298,7 @@ QVariantList recentDocumentActions(KService::Ptr service)
             continue;
         }
 
-        const KFileItem fileItem(url);
+        const KFileItem fileItem(url, mimeType);
 
         if (!fileItem.isFile()) {
             continue;
@@ -429,14 +431,13 @@ QVariantList appstreamActions(const KService::Ptr &service)
         appstreamPool->load();
     }
 
-    const auto components =
-        appstreamPool->componentsByLaunchable(AppStream::Launchable::KindDesktopId, service->desktopEntryName() + QLatin1String(".desktop"));
+    const auto components = appstreamPool->componentsById(service->desktopEntryName() + QLatin1String(".desktop"));
     for (const auto &component : components) {
         const QString componentId = component.id();
 
         QVariantMap appstreamAction = Kicker::createActionItem(i18nc("@action opens a software center with the application", "Uninstall or Manage Add-Ons…"),
                                                                appStreamHandler->icon(),
-                                                               "manageApplication",
+                                                               QStringLiteral("manageApplication"),
                                                                QVariant(QLatin1String("appstream://") + componentId));
         // Only process the first element. In case we have system provided and flatpack sources we would end up with duplicated entries
         return {appstreamAction};
@@ -457,6 +458,53 @@ bool handleAppstreamActions(const QString &actionId, const QVariant &argument)
     return false;
 }
 
+static QList<KServiceAction> additionalActions(const KService::Ptr &service)
+{
+    QList<KServiceAction> actions;
+    const static auto locations =
+        QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("plasma/kickeractions"), QStandardPaths::LocateDirectory);
+    const auto files = KFileUtils::findAllUniqueFiles(locations);
+    for (const auto &file : files) {
+        KService actionsService(file);
+        const auto filter = actionsService.property(QStringLiteral("X-KDE-OnlyForAppIds"), QVariant::StringList).toStringList();
+        if (filter.empty() || filter.contains(storageIdFromService(service))) {
+            actions.append(KDesktopFileActions::userDefinedServices(actionsService, true));
+        }
+    }
+    return actions;
+}
+
+QVariantList additionalAppActions(const KService::Ptr &service)
+{
+    QVariantList list;
+    const auto actions = additionalActions(service);
+    list.reserve(actions.size());
+    for (const auto &action : actions) {
+        list << createActionItem(action.text(), action.icon(), action.name(), action.service()->entryPath());
+    }
+    return list;
+}
+
+bool handleAdditionalAppActions(const QString &actionId, const KService::Ptr &service, const QVariant &argument)
+{
+    const KService actionProvider(argument.toString());
+    if (!actionProvider.isValid()) {
+        return false;
+    }
+    const auto actions = actionProvider.actions();
+    auto action = std::find_if(actions.begin(), actions.end(), [&actionId](const KServiceAction &action) {
+        return action.name() == actionId;
+    });
+    if (action == actions.end()) {
+        return false;
+    }
+    auto *job = new KIO::ApplicationLauncherJob(*action);
+    job->setUrls({QUrl::fromLocalFile(resolvedServiceEntryPath(service))});
+    job->setUiDelegate(new KNotificationJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled));
+    job->start();
+    return true;
+}
+
 QString resolvedServiceEntryPath(const KService::Ptr &service)
 {
     QString path = service->entryPath();
