@@ -122,20 +122,18 @@ QVariant RunnerMatchesModel::data(const QModelIndex &index, int role) const
             }
 
             const QVariantList &addLauncherActions = Kicker::createAddLauncherActionList(appletInterface, service);
-            bool needsSeparator = false;
             if (!systemImmutable && !addLauncherActions.isEmpty()) {
-                actionList << addLauncherActions;
-                needsSeparator = true;
+                actionList << addLauncherActions << Kicker::createSeparatorActionItem();
             }
 
             const QVariantList &recentDocuments = Kicker::recentDocumentActions(service);
             if (!recentDocuments.isEmpty()) {
-                actionList << recentDocuments;
-                needsSeparator = false;
+                actionList << recentDocuments << Kicker::createSeparatorActionItem();
             }
 
-            if (needsSeparator) {
-                actionList << Kicker::createSeparatorActionItem();
+            const QVariantList &additionalActions = Kicker::additionalAppActions(service);
+            if (!additionalActions.isEmpty()) {
+                actionList << additionalActions << Kicker::createSeparatorActionItem();
             }
 
             // Don't allow adding launchers, editing, hiding, or uninstalling applications
@@ -216,6 +214,8 @@ bool RunnerMatchesModel::trigger(int row, const QString &actionId, const QVarian
         return job->exec();
     } else if (actionId == QLatin1String("_kicker_recentDocument") || actionId == QLatin1String("_kicker_forgetRecentDocuments")) {
         return Kicker::handleRecentDocumentAction(service, actionId, argument);
+    } else if (Kicker::handleAdditionalAppActions(actionId, service, argument)) {
+        return true;
     }
 
     return false;
