@@ -19,6 +19,8 @@
 
 #include <algorithm>
 
+#include "colorsapplicator.h"
+
 ColorsModel::ColorsModel(QObject *parent)
     : QAbstractListModel(parent)
 {
@@ -58,6 +60,12 @@ QVariant ColorsModel::data(const QModelIndex &index, int role) const
         return item.pendingDeletion;
     case RemovableRole:
         return item.removable;
+    case AccentActiveTitlebarRole:
+        return item.accentActiveTitlebar;
+    case Tints:
+        return item.tints;
+    case TintFactor:
+        return item.tintFactor;
     }
 
     return QVariant();
@@ -103,7 +111,10 @@ QHash<int, QByteArray> ColorsModel::roleNames() const
         {ActiveTitleBarBackgroundRole, QByteArrayLiteral("activeTitleBarBackground")},
         {ActiveTitleBarForegroundRole, QByteArrayLiteral("activeTitleBarForeground")},
         {RemovableRole, QByteArrayLiteral("removable")},
+        {AccentActiveTitlebarRole, QByteArrayLiteral("accentActiveTitlebar")},
         {PendingDeletionRole, QByteArrayLiteral("pendingDeletion")},
+        {Tints, QByteArrayLiteral("tints")},
+        {TintFactor, QByteArrayLiteral("tintFactor")},
     };
 }
 
@@ -190,6 +201,8 @@ void ColorsModel::load()
             activeTitleBarForeground = wmConfig.readEntry("activeForeground", palette.color(QPalette::Active, QPalette::HighlightedText));
         }
 
+        const bool colorActiveTitleBar = group.readEntry("accentActiveTitlebar", false);
+
         ColorsModelData item{
             name,
             baseName,
@@ -197,7 +210,10 @@ void ColorsModel::load()
             activeTitleBarBackground,
             activeTitleBarForeground,
             fi.isWritable(),
+            colorActiveTitleBar,
             false, // pending deletion
+            group.hasKey("TintFactor"),
+            group.readEntry<qreal>("TintFactor", DefaultTintFactor),
         };
 
         m_data.append(item);
