@@ -3,6 +3,7 @@
     SPDX-FileCopyrightText: 2014 Vishesh Handa <me@vhanda.in>
     SPDX-FileCopyrightText: 2019 Cyril Rossi <cyril.rossi@enioka.com>
     SPDX-FileCopyrightText: 2021 Benjamin Port <benjamin.port@enioka.com>
+    SPDX-FileCopyrightText: 2022 Dominic Hayes <ferenosdev@outlook.com>
 
     SPDX-License-Identifier: LGPL-2.0-only
 */
@@ -14,7 +15,6 @@
 #include "lookandfeeldata.h"
 #include "lookandfeelsettings.h"
 #include <KIO/CommandLauncherJob>
-#include <KService>
 #include <KSharedConfig>
 #include <QDBusConnection>
 #include <QDBusMessage>
@@ -27,6 +27,10 @@
 LookAndFeelManager::LookAndFeelManager(QObject *parent)
     : QObject(parent)
     , m_data(new LookAndFeelData(this))
+    , m_appearanceToApply(LookAndFeelManager::AppearanceToApply(LookAndFeelManager::AppearanceSettings))
+    , m_layoutToApply(LookAndFeelManager::LayoutToApply(LookAndFeelManager::LayoutSettings))
+    , m_plasmashellChanged(false)
+    , m_fontsChanged(false)
 {
     m_applyLatteLayout = (KService::serviceByDesktopName("org.kde.latte-dock") != nullptr);
 }
@@ -36,6 +40,34 @@ LookAndFeelSettings *LookAndFeelManager::settings() const
     return m_data->settings();
 }
 
+void LookAndFeelManager::setAppearanceToApply(AppearanceToApply items)
+{
+    if (m_appearanceToApply == items) {
+        return;
+    }
+    m_appearanceToApply = items;
+    Q_EMIT appearanceToApplyChanged();
+}
+
+LookAndFeelManager::AppearanceToApply LookAndFeelManager::appearanceToApply() const
+{
+    return m_appearanceToApply;
+}
+
+void LookAndFeelManager::setLayoutToApply(LayoutToApply items)
+{
+    if (m_layoutToApply == items) {
+        return;
+    }
+    m_layoutToApply = items;
+    Q_EMIT layoutToApplyChanged();
+}
+
+LookAndFeelManager::LayoutToApply LookAndFeelManager::layoutToApply() const
+{
+    return m_layoutToApply;
+}
+
 void LookAndFeelManager::setSplashScreen(const QString &theme)
 {
     if (theme.isEmpty()) {
@@ -137,13 +169,12 @@ void LookAndFeelManager::setColors(const QString &scheme, const QString &colorFi
 
     KConfig configDefault(configDefaults(QStringLiteral("kdeglobals")));
     auto kdeGlobalsCfg = KSharedConfig::openConfig(QStringLiteral("kdeglobals"), KConfig::FullConfig);
+    writeNewDefaults(*kdeGlobalsCfg, configDefault, QStringLiteral("General"), QStringLiteral("ColorScheme"), scheme, KConfig::Notify);
 
     if (m_mode == Mode::Apply) {
         applyScheme(colorFile, kdeGlobalsCfg.data(), KConfig::Notify);
     }
 
-    writeNewDefaults(*kdeGlobalsCfg, configDefault, QStringLiteral("General"), QStringLiteral("ColorScheme"), scheme, KConfig::Notify);
-
     Q_EMIT colorsChanged();
 }
 
@@ -189,18 +220,64 @@ void LookAndFeelManager::setPlasmaTheme(const QString &theme)
     writeNewDefaults(QStringLiteral("plasmarc"), QStringLiteral("Theme"), QStringLiteral("name"), theme);
 }
 
-void LookAndFeelManager::setResetDefaultLayout(bool reset)
+void LookAndFeelManager::setGeneralFont(const QString &font)
 {
-    if (m_resetDefaultLayout == reset) {
+    if (font.isEmpty()) {
         return;
     }
-    m_resetDefaultLayout = reset;
-    Q_EMIT resetDefaultLayoutChanged();
+
+    writeNewDefaults(QStringLiteral("kdeglobals"), QStringLiteral("General"), QStringLiteral("font"), font, KConfig::Notify);
+    m_fontsChanged = true;
 }
 
-bool LookAndFeelManager::resetDefaultLayout() const
+void LookAndFeelManager::setFixedFont(const QString &font)
 {
-    return m_resetDefaultLayout;
+    if (font.isEmpty()) {
+        return;
+    }
+
+    writeNewDefaults(QStringLiteral("kdeglobals"), QStringLiteral("General"), QStringLiteral("fixed"), font, KConfig::Notify);
+    m_fontsChanged = true;
+}
+
+void LookAndFeelManager::setSmallestReadableFont(const QString &font)
+{
+    if (font.isEmpty()) {
+        return;
+    }
+
+    writeNewDefaults(QStringLiteral("kdeglobals"), QStringLiteral("General"), QStringLiteral("smallestReadableFont"), font, KConfig::Notify);
+    m_fontsChanged = true;
+}
+
+void LookAndFeelManager::setToolbarFont(const QString &font)
+{
+    if (font.isEmpty()) {
+        return;
+    }
+
+    writeNewDefaults(QStringLiteral("kdeglobals"), QStringLiteral("General"), QStringLiteral("toolBarFont"), font, KConfig::Notify);
+    m_fontsChanged = true;
+}
+
+void LookAndFeelManager::setMenuFont(const QString &font)
+{
+    if (font.isEmpty()) {
+        return;
+    }
+
+    writeNewDefaults(QStringLiteral("kdeglobals"), QStringLiteral("General"), QStringLiteral("menuFont"), font, KConfig::Notify);
+    m_fontsChanged = true;
+}
+
+void LookAndFeelManager::setWindowTitleFont(const QString &font)
+{
+    if (font.isEmpty()) {
+        return;
+    }
+
+    writeNewDefaults(QStringLiteral("kdeglobals"), QStringLiteral("WM"), QStringLiteral("activeFont"), font, KConfig::Notify);
+    m_fontsChanged = true;
 }
 
 void LookAndFeelManager::writeNewDefaults(const QString &filename,
@@ -255,10 +332,9 @@ QString LookAndFeelManager::colorSchemeFile(const QString &schemeName) const
 {
     QString colorScheme(schemeName);
     colorScheme.remove(QLatin1Char('\'')); // So Foo's does not become FooS
-    QRegExp fixer(QStringLiteral("[\\W,.-]+(.?)"));
-    int offset;
-    while ((offset = fixer.indexIn(colorScheme)) >= 0) {
-        colorScheme.replace(offset, fixer.matchedLength(), fixer.cap(1).toUpper());
+    QRegularExpression fixer(QStringLiteral("[\\W,.-]+(.?)"));
+    for (auto match = fixer.match(colorScheme); match.hasMatch(); match = fixer.match(colorScheme)) {
+        colorScheme.replace(match.capturedStart(), match.capturedLength(), match.captured(1).toUpper());
     }
     colorScheme.replace(0, 1, colorScheme.at(0).toUpper());
 
@@ -282,7 +358,7 @@ QString LookAndFeelManager::colorSchemeFile(const QString &schemeName) const
 
 void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::Package &previousPackage)
 {
-    if (m_resetDefaultLayout && m_mode == Mode::Apply) {
+    if (m_layoutToApply.testFlag(LookAndFeelManager::DesktopLayout) && m_mode == Mode::Apply) {
         QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.kde.plasmashell"),
                                                               QStringLiteral("/PlasmaShell"),
                                                               QStringLiteral("org.kde.PlasmaShell"),
@@ -304,91 +380,121 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
         KSharedConfigPtr conf = KSharedConfig::openConfig(package.filePath("defaults"));
         KConfigGroup group(conf, "kdeglobals");
         group = KConfigGroup(&group, "KDE");
-        if (m_applyWidgetStyle) {
-            QString widgetStyle = group.readEntry("widgetStyle", QString());
-            // Some global themes refer to breeze's widgetStyle with a lowercase b.
-            if (widgetStyle == QStringLiteral("breeze")) {
-                widgetStyle = QStringLiteral("Breeze");
+        if (m_mode == Mode::Apply) {
+            if (m_appearanceToApply.testFlag(LookAndFeelManager::WidgetStyle)) {
+                QString widgetStyle = group.readEntry("widgetStyle", QString());
+                // Some global themes refer to breeze's widgetStyle with a lowercase b.
+                if (widgetStyle == QStringLiteral("breeze")) {
+                    widgetStyle = QStringLiteral("Breeze");
+                }
+
+                setWidgetStyle(widgetStyle);
             }
 
-            setWidgetStyle(widgetStyle);
-        }
+            if (m_appearanceToApply.testFlag(LookAndFeelManager::Colors)) {
+                QString colorsFile = package.filePath("colors");
+                KConfigGroup group(conf, "kdeglobals");
+                group = KConfigGroup(&group, "General");
+                QString colorScheme = group.readEntry("ColorScheme", QString());
 
-        if (m_applyColors) {
-            QString colorsFile = package.filePath("colors");
-            KConfigGroup group(conf, "kdeglobals");
-            group = KConfigGroup(&group, "General");
-            QString colorScheme = group.readEntry("ColorScheme", QString());
-
-            if (!colorsFile.isEmpty()) {
-                if (!colorScheme.isEmpty()) {
-                    setColors(colorScheme, colorsFile);
-                } else {
-                    setColors(package.metadata().name(), colorsFile);
-                }
-            } else if (!colorScheme.isEmpty()) {
-                QString path = colorSchemeFile(colorScheme);
-                if (!path.isEmpty()) {
-                    setColors(colorScheme, path);
+                if (!colorsFile.isEmpty()) {
+                    if (!colorScheme.isEmpty()) {
+                        setColors(colorScheme, colorsFile);
+                    } else {
+                        setColors(package.metadata().name(), colorsFile);
+                    }
+                } else if (!colorScheme.isEmpty()) {
+                    QString path = colorSchemeFile(colorScheme);
+                    if (!path.isEmpty()) {
+                        setColors(colorScheme, path);
+                    }
                 }
             }
-        }
 
-        if (m_applyIcons) {
-            group = KConfigGroup(conf, "kdeglobals");
-            group = KConfigGroup(&group, "Icons");
-            setIcons(group.readEntry("Theme", QString()));
-        }
+            if (m_appearanceToApply.testFlag(LookAndFeelManager::Icons)) {
+                group = KConfigGroup(conf, "kdeglobals");
+                group = KConfigGroup(&group, "Icons");
+                setIcons(group.readEntry("Theme", QString()));
+            }
 
-        if (m_applyPlasmaTheme) {
-            group = KConfigGroup(conf, "plasmarc");
-            group = KConfigGroup(&group, "Theme");
-            setPlasmaTheme(group.readEntry("name", QString()));
-        }
+            if (m_appearanceToApply.testFlag(LookAndFeelManager::PlasmaTheme)) {
+                group = KConfigGroup(conf, "plasmarc");
+                group = KConfigGroup(&group, "Theme");
+                setPlasmaTheme(group.readEntry("name", QString()));
+            }
 
-        if (m_applyCursors) {
-            group = KConfigGroup(conf, "kcminputrc");
-            group = KConfigGroup(&group, "Mouse");
-            setCursorTheme(group.readEntry("cursorTheme", QString()));
-        }
+            if (m_appearanceToApply.testFlag(LookAndFeelManager::Cursors)) {
+                group = KConfigGroup(conf, "kcminputrc");
+                group = KConfigGroup(&group, "Mouse");
+                setCursorTheme(group.readEntry("cursorTheme", QString()));
+            }
 
-        if (m_applyWindowSwitcher) {
-            group = KConfigGroup(conf, "kwinrc");
-            group = KConfigGroup(&group, "WindowSwitcher");
-            setWindowSwitcher(group.readEntry("LayoutName", QString()));
-        }
+            if (m_appearanceToApply.testFlag(LookAndFeelManager::WindowSwitcher)) {
+                group = KConfigGroup(conf, "kwinrc");
+                group = KConfigGroup(&group, "WindowSwitcher");
+                setWindowSwitcher(group.readEntry("LayoutName", QString()));
+            }
 
-        if (m_applyDesktopSwitcher) {
-            group = KConfigGroup(conf, "kwinrc");
-            group = KConfigGroup(&group, "DesktopSwitcher");
-            setDesktopSwitcher(group.readEntry("LayoutName", QString()));
-        }
+            if (m_layoutToApply.testFlag(LookAndFeelManager::DesktopSwitcher)) {
+                group = KConfigGroup(conf, "kwinrc");
+                group = KConfigGroup(&group, "DesktopSwitcher");
+                setDesktopSwitcher(group.readEntry("LayoutName", QString()));
+            }
 
-        if (m_applyWindowPlacement) {
-            group = KConfigGroup(conf, "kwinrc");
-            group = KConfigGroup(&group, "Windows");
-            setWindowPlacement(group.readEntry("Placement", QStringLiteral("Centered")));
-        }
+            if (m_layoutToApply.testFlag(LookAndFeelManager::WindowPlacement)) {
+                group = KConfigGroup(conf, "kwinrc");
+                group = KConfigGroup(&group, "Windows");
+                setWindowPlacement(group.readEntry("Placement", QStringLiteral("Centered")));
+            }
 
-        if (m_applyShellPackage) {
-            group = KConfigGroup(conf, "plasmashellrc");
-            group = KConfigGroup(&group, "Shell");
-            setShellPackage(group.readEntry("ShellPackage", QString()));
-        }
+            if (m_layoutToApply.testFlag(LookAndFeelManager::ShellPackage)) {
+                group = KConfigGroup(conf, "plasmashellrc");
+                group = KConfigGroup(&group, "Shell");
+                setShellPackage(group.readEntry("ShellPackage", QString()));
+            }
 
-        if (m_applyWindowDecoration) {
-            group = KConfigGroup(conf, "kwinrc");
-            group = KConfigGroup(&group, "org.kde.kdecoration2");
+            if (m_appearanceToApply.testFlag(LookAndFeelManager::WindowDecoration)) {
+                group = KConfigGroup(conf, "kwinrc");
+                group = KConfigGroup(&group, "org.kde.kdecoration2");
 #ifdef HAVE_BREEZE_DECO
-            setWindowDecoration(group.readEntry("library", QStringLiteral(BREEZE_KDECORATION_PLUGIN_ID)), group.readEntry("theme", QStringLiteral("Breeze")));
+                setWindowDecoration(group.readEntry("library", QStringLiteral(BREEZE_KDECORATION_PLUGIN_ID)), group.readEntry("theme", QStringLiteral("Breeze")));
 #else
-            setWindowDecoration(group.readEntry("library", QStringLiteral("org.kde.kwin.aurorae")),
-                                group.readEntry("theme", QStringLiteral("kwin4_decoration_qml_plastik")));
+                setWindowDecoration(group.readEntry("library", QStringLiteral("org.kde.kwin.aurorae")),
+                                    group.readEntry("theme", QStringLiteral("kwin4_decoration_qml_plastik")));
 #endif
-        }
+            }
 
-        setSplashScreen(m_data->settings()->lookAndFeelPackage());
-        setLockScreen(m_data->settings()->lookAndFeelPackage());
+            if (m_appearanceToApply.testFlag(LookAndFeelManager::Fonts)) {
+                group = KConfigGroup(conf, "kdeglobals");
+                group = KConfigGroup(&group, "General");
+                setGeneralFont(group.readEntry("font", QString()));
+                setFixedFont(group.readEntry("fixed", QString()));
+                setSmallestReadableFont(group.readEntry("smallestReadableFont", QString()));
+                setToolbarFont(group.readEntry("toolBarFont", QString()));
+                setMenuFont(group.readEntry("menuFont", QString()));
+                group = KConfigGroup(conf, "kdeglobals");
+                group = KConfigGroup(&group, "WM");
+                setWindowTitleFont(group.readEntry("activeFont"));
+                if (m_fontsChanged) {
+                    Q_EMIT fontsChanged();
+                    m_fontsChanged = false;
+                }
+            }
+
+            if (m_appearanceToApply.testFlag(LookAndFeelManager::SplashScreen)) {
+                group = KConfigGroup(conf, "ksplashrc");
+                group = KConfigGroup(&group, "KSplash");
+                QString splashScreen = (group.readEntry("Theme", QString()));
+                if (!splashScreen.isEmpty()) {
+                    setSplashScreen(splashScreen);
+                } else {
+                    setSplashScreen(m_data->settings()->lookAndFeelPackage());
+                }
+            }
+            if (m_appearanceToApply.testFlag(LookAndFeelManager::LockScreen)) {
+                setLockScreen(m_data->settings()->lookAndFeelPackage());
+            }
+        }
 
         QFile packageFile(QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + QLatin1String("/kdedefaults/package"));
         packageFile.open(QIODevice::WriteOnly);
@@ -399,7 +505,7 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
         }
 
         // Reload KWin if something changed, but only once.
-        if (m_applyWindowSwitcher || m_applyDesktopSwitcher || m_applyWindowDecoration || m_applyWindowPlacement) {
+        if (m_appearanceToApply.testFlag(LookAndFeelManager::WindowSwitcher) || m_layoutToApply.testFlag(LookAndFeelManager::DesktopSwitcher) || m_appearanceToApply.testFlag(LookAndFeelManager::WindowDecoration) || m_layoutToApply.testFlag(LookAndFeelManager::WindowPlacement)) {
             QDBusMessage message = QDBusMessage::createSignal(QStringLiteral("/KWin"), QStringLiteral("org.kde.KWin"), QStringLiteral("reloadConfig"));
             QDBusConnection::sessionBus().send(message);
         }
@@ -411,7 +517,7 @@ void LookAndFeelManager::save(const KPackage::Package &package, const KPackage::
         }
 
         // autostart
-        if (m_resetDefaultLayout) {
+        if (m_layoutToApply.testFlag(LookAndFeelManager::DesktopLayout)) {
             QStringList toStop;
             KService::List toStart;
             // remove all the old package to autostart
