@@ -5,6 +5,7 @@
 */
 
 #include "virtualdesktopinfo.h"
+#include "libtaskmanager_debug.h"
 
 #include <KLocalizedString>
 #include <KWayland/Client/connection_thread.h>
@@ -21,7 +22,11 @@
 #include <config-X11.h>
 
 #if HAVE_X11
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
+#endif
 #include <netwm.h>
 #endif
 
@@ -76,7 +81,7 @@ VirtualDesktopInfo::Private::Private()
                                                                   this,
                                                                   SLOT(navigationWrappingAroundChanged(bool)));
     if (!connection) {
-        qWarning() << "Could not connect to org.kde.KWin.VirtualDesktopManager.navigationWrappingAroundChanged signal";
+        qCWarning(TASKMANAGER_DEBUG) << "Could not connect to org.kde.KWin.VirtualDesktopManager.navigationWrappingAroundChanged signal";
     }
 
     // ...Then get the property's current value
@@ -91,7 +96,7 @@ VirtualDesktopInfo::Private::Private()
         watcher->deleteLater();
 
         if (reply.isError()) {
-            qWarning() << "Failed to determine whether virtual desktop navigation wrapping is enabled: " << reply.error().message();
+            qCWarning(TASKMANAGER_DEBUG) << "Failed to determine whether virtual desktop navigation wrapping is enabled: " << reply.error().message();
             return;
         }
 
