@@ -19,7 +19,6 @@
 #include <QSessionManager>
 
 #include <KAboutData>
-#include <KQuickAddons/QtQuickSettings>
 
 #ifdef WITH_KUSERFEEDBACKCORE
 #include "userfeedback.h"
@@ -31,6 +30,7 @@
 #include <kworkspace.h>
 
 #include "coronatesthelper.h"
+#include "debug.h"
 #include "shellcorona.h"
 #include "softwarerendernotifier.h"
 #include "standaloneappcorona.h"
@@ -55,9 +55,11 @@ void filterConnectionSyntaxWarning(QLoggingCategory *category)
 
 int main(int argc, char *argv[])
 {
+#if QT_CONFIG(qml_debug)
     if (qEnvironmentVariableIsSet("PLASMA_ENABLE_QML_DEBUG")) {
         QQmlDebuggingEnabler debugger;
     }
+#endif
     // Plasma scales itself to font DPI
     // on X, where we don't have compositor scaling, this generally works fine.
     // also there are bugs on older Qt, especially when it comes to fractional scaling
@@ -90,8 +92,6 @@ int main(int argc, char *argv[])
     // This does not make much sense for plasmashell.
     app.removeLibraryPath(QCoreApplication::applicationDirPath());
 
-    KQuickAddons::QtQuickSettings::init();
-
     KAboutData aboutData(QStringLiteral("plasmashell"), i18n("Plasma"), QStringLiteral(PROJECT_VERSION), i18n("Plasma Shell"), KAboutLicense::GPL);
 
     KAboutData::setApplicationData(aboutData);
@@ -141,7 +141,9 @@ int main(int argc, char *argv[])
         cliOptions.process(app);
         aboutData.processCommandLine(&cliOptions);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         QGuiApplication::setFallbackSessionManagementEnabled(false);
+#endif
 
         auto disableSessionManagement = [](QSessionManager &sm) {
             sm.setRestartHint(QSessionManager::RestartNever);
@@ -173,7 +175,7 @@ int main(int argc, char *argv[])
         if (cliOptions.isSet(testOption)) {
             const QUrl layoutUrl = QUrl::fromUserInput(cliOptions.value(testOption), {}, QUrl::AssumeLocalFile);
             if (!layoutUrl.isLocalFile()) {
-                qWarning() << "ensure the layout file is local" << layoutUrl;
+                qCWarning(PLASMASHELL) << "ensure the layout file is local" << layoutUrl;
                 cliOptions.showHelp(1);
             }
 
